@@ -103,10 +103,65 @@ ColorButton::is_force_needed ()
 {
 	static const char *OFFENDING_THEMES[] = 
 	{
+		"Adwaita",
+		"Adwaita-dark",
 		"Amaranth",
 		"Lush",
 		"Nuvola",
 		"New Wave",
+		"Mint-X",
+		"Mint-X-Aqua",
+		"Mint-X-Blue",
+		"Mint-X-Brown",
+		"Mint-X-Grey",
+		"Mint-X-Orange",
+		"Mint-X-Pink",
+		"Mint-X-Purple",
+		"Mint-X-Red",
+		"Mint-X-Sand",
+		"Mint-X-Teal",
+		"Mint-Y",
+		"Mint-Y-Aqua",
+		"Mint-Y-Blue",
+		"Mint-Y-Brown",
+		"Mint-Y-Dark",
+		"Mint-Y-Red",
+		"Mint-Y-Dark-Red",
+		"Mint-Y-Dark-Aqua",
+		"Mint-Y-Dark-Blue",
+		"Mint-Y-Dark-Brown",
+		"Mint-Y-Darker-Aqua",
+		"Mint-Y-Darker-Blue",
+		"Mint-Y-Darker-Brown",
+		"Mint-Y-Darker-Grey",
+		"Mint-Y-Darker-Orange",
+		"Mint-Y-Darker-Pink",
+		"Mint-Y-Darker-Purple",
+		"Mint-Y-Darker-Red",
+		"Mint-Y-Darker-Sand",
+		"Mint-Y-Darker-Teal",
+		"Mint-Y-Dark-Grey",
+		"Mint-Y-Dark-Orange",
+		"Mint-Y-Dark-Pink",
+		"Mint-Y-Dark-Purple",
+		"Mint-Y-Dark-Sand",
+		"Mint-Y-Dark-Teal",
+		"Mint-Y-Grey",
+		"Mint-Y-Orange",
+		"Mint-Y-Pink",
+		"Mint-Y-Purple",
+		"Mint-Y-Sand",
+		"Mint-Y-Teal",
+		"WhiteSur",
+		"WhiteSur-light",
+		"WhiteSur-dark",
+		"WhiteSur-light-solid",
+		"WhiteSur-dark-solid",
+		"Yaru",
+		"Yaru-dark",
+		"Yaru-light",
+		"Yaru-MATE-dark",
+		"Yaru-MATE-light",
 		NULL
 	};
 
