@@ -82,7 +82,7 @@ main (int& argc, char**& argv)
 		{
 			std::locale::global (std::locale (std::setlocale (LC_ALL, NULL)));
 		}
-		catch (std::runtime_error)
+		catch (const std::runtime_error &)
 		{
 			std::locale::global (std::locale::classic ());
 		}
@@ -360,7 +360,7 @@ MainWindow::on_about ()
 
 	about.set_copyright
 	(
-		"Copyright © 2016-2019 Graham Inggs\n"
+		"Copyright © 2016-2021 Graham Inggs\n"
 		"Copyright © 2006-2007 Kevin Daughtridge\n"
 		"Copyright © 2003 Jonas Frantz"
 	);
